#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-abstraction
version:              0.6.0.0
visibility:           public
id:                   th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
key:                  th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  28c84ce74e4f091d8e50ce0b31de05f5
exposed:              True
exposed-modules:
    Language.Haskell.TH.Datatype Language.Haskell.TH.Datatype.TyVarBndr

hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-abstraction-0.6.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-abstraction-0.6.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-abstraction-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-abstraction
hs-libraries:         HSth-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
depends:
    base-4.18.2.1 containers-0.6.7 ghc-prim-0.10.0
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

